# Designed for DermAnnotation

This is an utility python package to deal with tiff images
created by [DermAnnotation](https://kondoa9.github.io/DermAnnotation/en/).

Examples are [example/example.md](example/example.md).

## Release Note

- 2.0.0: デフォルトの圧縮方式を`tiff_adobe_deflate`に変更

- 1.0.6: 圧縮方式を`tiff_adobe_deflate`から`tiff_lzw`に変更
- 1.0.5: パッケージ名をDermAnnoからDermTiffに変更